You might not have noticed, but [[2a. Action to modify specific url only and alerts user otherwise - background.js with content.js]]'s sendMessage is a bit different.

Here are two variants:

## Variant A - sendMessage
- For background (if messaging itself or messaging to background)
- For popup and other extension pages, BUT NOT content

background.js:
```
chrome.tabs.query({ active: true, currentWindow: true }, function(tabs) {
	chrome.runtime.sendMessage({ type: 'SOME_MESSAGE_NAME', tabId: tabs[0].id, href, message: "NOT_GOOGLE" });
});
```
^ `tabId: tabs[0].id,` is not necessary UNLESS later code (at the receiving end) needs to get the tabId. Remember that the receiving end gets access to the object "arguments" passed to it, and getting the value of type (which is "activeTab") may be pointless. So it's a good practice to include it anyways if you're unsure.

content.js:
```
chrome.runtime.onMessage.addListener(async function (request, sender, sendResponse) {
	switch (request.message) {
		case "SOME_MESSAGE_NAME":
			alert("This isn't Google! Run the Chrome extension (clicking the icon) when on a google page.")
			break;
	}
});
```


## Variant B - sendMessage
- For background (if messaging itself or messaging to background)
- For content and other extension pages, BUT NOT popup

background.js:
```
chrome.tabs.query({ active: true, currentWindow: true }, function(tabs) {
	chrome.tabs.sendMessage(tabs[0].id, { message: "SOME_MESSAGE_NAME" });
});
```

content.js (same):
```
chrome.runtime.onMessage.addListener(async function (request, sender, sendResponse) {
	switch (request.message) {
		case "SOME_MESSAGE_NAME":
			alert("This isn't Google! Run the Chrome extension (clicking the icon) when on a google page.")
			break;
	}
});
```

## Thinking about Syntax

The receiving end is the same syntax in either Variant A or Variant B.

The sending end could be either variant A or variant B depending on who you're sending to. It may be annoying to memorize, so if you find variant A doesn't work, then you try variant B.

You may think of using Cursor AI or VS Code Copilot to generate the sendMessage (because it could detect there's a popup.js, content.js, or both, etc) but it's not smart enough. As of 3/2025, it generates a mixed version of variant A and variant B that does not work at all.

Adding other properties (key/values) make them additional properties that can be accessed at the receiving end. It's recommended that your additional property isn't keyed as "type" because as you can see, variant A uses the property "type" to determine to send to active tab, whereas "type" in variant B can be a custom key, and that can make you conflate the two syntaxes. We've decided to use a key called "message" to determine the actual "type" of the message at the receiving end's switch statement. Usually you have a switch statement on the receiving end, because it could receive various types of messages and act accordingly (even if at the current use case, you only need to send any message to have the other part of your chrome extension to run code, you want to build for scalability and future possible use cases and features).
